@@ -1,4 +1,4 @@
-# Copyright (C) 2014 - 2016  Jack O. Wasey
+# Copyright (C) 2014 - 2017  Jack O. Wasey
 #
 # This file is part of icd.
 #
@@ -65,16 +65,19 @@ icd_children.character <- function(x, ...) {
 #' @describeIn icd_children Get children of ICD-9 codes
 #' @export
 icd_children.icd9 <- function(x, short_code = icd_guess_short(x),
-                              defined = TRUE, billable = FALSE, ...) {
+                              defined = TRUE, billable = FALSE, debug = FALSE, ...) {
   assert(check_factor(x), check_character(x))
   assert_flag(short_code)
   assert_flag(defined)
   assert_flag(billable)
 
-  if (short_code)
-    res <- .Call("icd_icd9ChildrenShortCpp", PACKAGE = "icd", toupper(x), defined)
+  # TODO order/unorder consistently for decimal and short
+  res <- if (short_code)
+    .Call("icd_icd9ChildrenShortUnordered", toupper(x), defined)
   else
-    res <- .Call("icd_icd9ChildrenDecimalCpp", PACKAGE = "icd", toupper(x), defined)
+    .Call("icd_icd9ChildrenDecimalCpp", toupper(x), defined)
+
+  res <- icd_sort.icd9(res)
 
   if (billable)
     icd_get_billable.icd9cm(icd9cm(res), short_code)
