@@ -1,4 +1,4 @@
-// Copyright (C) 2014 - 2016  Jack O. Wasey
+// Copyright (C) 2014 - 2017  Jack O. Wasey
 //
 // This file is part of icd.
 //
@@ -19,24 +19,21 @@
 // [[Rcpp::plugins(openmp)]]
 #include "local.h"
 #include "util.h"
-//#ifdef ICD_STD_PARALLEL
-// this will probably make things worse if already in an OpenMP block, unless I
-// can dynamically see how many threads are available or active.
-//#include <parallel/algorithm>
-//#else
 #include <algorithm>
-//#endif
 
+//' core search for ICD code in a map
+//' @keywords internal
+// [[Rcpp::export]]
 void lookupComorbidByChunkFor(const VecVecInt& vcdb,
                               const VecVecInt& map,
                               const VecVecIntSz chunkSize,
                               const VecVecIntSz ompChunkSize,
                               ComorbidOut& out) {
   const VecVecIntSz num_comorbid = map.size();
-  const VecVecIntSz num_visits = vcdb.size();
-  const VecVecIntSz last_i = num_visits - 1;
+  const VecVecIntSz last_i = vcdb.size() - 1;
   VecVecIntSz chunk_end_i;
   VecVecIntSz vis_i;
+  const VecVecIntSz vsz = vcdb.size();
 #ifdef ICD_DEBUG_TRACE
   Rcpp::Rcout << "vcdb.size() = " << vcdb.size() << "\n";
   Rcpp::Rcout << "map.size() = " << map.size() << "\n";
@@ -46,52 +43,44 @@ void lookupComorbidByChunkFor(const VecVecInt& vcdb,
 #endif
 
 #ifdef ICD_OPENMP
-  // I think const values are automatically shared, if default(none) is not used. Different compilers respond differently.
 #pragma omp parallel for schedule(static) default(none) shared(out, Rcpp::Rcout, vcdb, map) private(chunk_end_i, vis_i)
   // SOMEDAY: need to consider other processes using multiple cores, see Writing R Extensions.
   //	omp_set_schedule(omp_sched_static, ompChunkSize);
-  // #pragma omp for schedule(static)
 #endif
-  // loop through chunks at a time
-  for (vis_i = 0; vis_i < num_visits; vis_i += chunkSize) {
+  // loop through chunks at a time, by integer size:
+  // https://stackoverflow.com/questions/2513988/iteration-through-std-containers-in-openmp
+  for (vis_i = 0; vis_i < vsz; vis_i += chunkSize) {
 #ifdef ICD_DEBUG_TRACE
     Rcpp::Rcout << "vis_i = " << vis_i << "\n";
 #endif
 #ifdef ICD_DEBUG_PARALLEL
     debug_parallel();
 #endif
-    chunk_end_i = vis_i + chunkSize - 1; // chunk end is an index, so for zero-based vis_i and chunk_end should be the last index in the chunk
+    // chunk end is an index, so for zero-based vis_i and chunk_end should be
+    // the last index in the chunk
+    chunk_end_i = vis_i + chunkSize - 1;
     if (chunk_end_i > last_i)
-      chunk_end_i = last_i; // indices
+      chunk_end_i = last_i;
     ComorbidOut chunk;
 #ifdef ICD_DEBUG_TRACE
-    // this gives size 0 with OMP enabled. bug #75 unravelling: this isn't zero!
     Rcpp::Rcout << "OMP vcdb.size() = " << vcdb.size() << "\n";
     Rcpp::Rcout << "OMP map.size() = " << map.size() << "\n";
 #endif
-    // lookupOneChunk(vcdb, map, num_comorbid, vis_i, chunk_end_i, chunk);
-    // Look up comorbidities for one chunk of vcdb, this is called in parallel
-    //		void lookupOneChunk(const VecVecInt& vcdb, const VecVecInt& map,
-    //const VecVecIntSz num_comorbid, const VecVecIntSz begin,
-    //const VecVecIntSz end, ComorbidOut& chunk) {
-    VecVecIntSz begin = vis_i;
-    VecVecIntSz end = chunk_end_i;
+    const VecVecIntSz& begin = vis_i;
+    const VecVecIntSz& end = chunk_end_i;
 
 #ifdef ICD_DEBUG_TRACE
     Rcpp::Rcout << "lookupComorbidChunk begin = " << begin << ", end = " << end << "\n";
 #endif
-    const ComorbidOut falseComorbidChunk(num_comorbid * (1 + end - begin),
-                                         false);
+    const ComorbidOut falseComorbidChunk(num_comorbid * (1 + end - begin), false);
     chunk = falseComorbidChunk;
     for (VecVecIntSz urow = begin; urow <= end; ++urow) { //end is index of end of chunk, so we include it in the loop.
 #ifdef ICD_DEBUG_TRACE
-      // with OpenMP, vcdb.size() gives massive number, but the correct value without OpenMP.
       Rcpp::Rcout << "row: " << 1 + urow - begin << " of " << 1 + end - begin << "\n";
 #endif
       for (VecVecIntSz cmb = 0; cmb < num_comorbid; ++cmb) { // loop through icd codes for this visitId
 #ifdef ICD_DEBUG_TRACE
         Rcpp::Rcout << "cmb = " << cmb << "\n";
-        // with OpenMP, vcdb.size() gives massive number, but the correct value without OpenMP.
         Rcpp::Rcout << "vcdb length in lookupOneChunk = " << vcdb.size() << "\n";
         Rcpp::Rcout << "map length in lookupOneChunk = " << map.size() << "\n";
 #endif
@@ -122,7 +111,8 @@ void lookupComorbidByChunkFor(const VecVecInt& vcdb,
     Rcpp::Rcout << "finished with one chunk\n";
 #endif
 
-    // next block doesn't need to be single threaded(?), but doing so improves cache contention
+    // next block doesn't need to be single threaded(?), but doing so improves
+    // cache contention
 #ifdef ICD_OPENMP
 #pragma omp critical
 #endif
@@ -130,7 +120,7 @@ void lookupComorbidByChunkFor(const VecVecInt& vcdb,
 #ifdef ICD_DEBUG_TRACE
   Rcpp::Rcout << "writing a chunk beginning at: " << vis_i << "\n";
 #endif
-  // write out calculated data to the output matrix (must sync threads here, hence omp critical
+  // write calculated data to the output matrix (must sync threads before this)
   std::copy(chunk.begin(), chunk.end(),
             out.begin() + (num_comorbid * vis_i));
 }
@@ -141,16 +131,15 @@ void lookupComorbidByChunkFor(const VecVecInt& vcdb,
 #endif
 }
 
-// just return the chunk results: this shouldn't cause invalidation of shared 'out'
-ComorbidOut lookupComorbidByChunkFor(const VecVecInt& vcdb,
-                                     const VecVecInt& map, const int chunkSize, const int ompChunkSize) {
+ComorbidOut lookupComorbidByChunkFor(const VecVecInt& vcdb, const VecVecInt& map,
+                                     const int chunkSize, const int ompChunkSize) {
   // initialize output matrix with all false for all comorbidities
   ComorbidOut out(vcdb.size() * map.size(), false);
 #ifdef ICD_DEBUG_TRACE
   Rcpp::Rcout << "top level vcdb.size() = " << vcdb.size() << "\n";
   Rcpp::Rcout << "top level map.size() = " << map.size() << "\n";
 #endif
-  //SOMEDAY: can I pass the output by reference, instead?
+  //TODO: pass the output by reference, instead?
   lookupComorbidByChunkFor(vcdb, map, chunkSize, ompChunkSize, out);
   return out;
 }
