@@ -1,4 +1,4 @@
-// Copyright (C) 2014 - 2016  Jack O. Wasey
+// Copyright (C) 2014 - 2017  Jack O. Wasey
 //
 // This file is part of icd.
 //
@@ -17,14 +17,15 @@
 
 #ifndef IS_H_
 #define IS_H_
+#include "icd_types.h"
 #include <string>
 #include <vector>
 
 bool icd9IsASingleV(const char* s);
 bool icd9IsASingleE(const char* s);
 bool icd9IsASingleVE(const char* s);
-std::vector<bool> icd9_is_n_cpp(const std::vector<std::string>& sv);
-std::vector<bool> icd9_is_v_cpp(const std::vector<std::string>& sv);
-std::vector<bool> icd9_is_e_cpp(const std::vector<std::string>& sv);
+std::vector<bool> icd9_is_n_cpp(const VecStr& sv);
+std::vector<bool> icd9_is_v_cpp(const VecStr& sv);
+std::vector<bool> icd9_is_e_cpp(const VecStr& sv);
 
 #endif /* IS_H_ */
