@@ -1,4 +1,4 @@
-// Copyright (C) 2014 - 2016  Jack O. Wasey
+// Copyright (C) 2014 - 2017  Jack O. Wasey
 //
 // This file is part of icd.
 //
@@ -37,18 +37,15 @@ int getOmpThreads();
 int getOmpMaxThreads();
 void debug_parallel();
 Rcpp::NumericVector randomMajorCpp(int n);
-std::vector<std::string> icd9RandomShortN(std::vector<std::string>::size_type n);
-std::vector<std::string> icd9RandomShortV(std::vector<std::string>::size_type n);
-std::vector<std::string> icd9RandomShortE(std::vector<std::string>::size_type n);
-std::vector<std::string> icd9RandomShort(std::vector<std::string>::size_type n);
-
-std::vector<std::string> fastIntToStringStd(std::vector<int> x);
-Rcpp::CharacterVector fastIntToStringRcpp(Rcpp::IntegerVector x);
+VecStr icd9RandomShortN(VecStr::size_type n);
+VecStr icd9RandomShortV(VecStr::size_type n);
+VecStr icd9RandomShortE(VecStr::size_type n);
+VecStr icd9RandomShort(VecStr::size_type n);
 
 int valgrindCallgrindStart(bool zerostats);
 int valgrindCallgrindStop();
 
 bool icd9CompareStrings(std::string a, std::string b);
-std::vector<std::size_t> icd9OrderCpp(std::vector<std::string> x);
+std::vector<std::size_t> icd9OrderCpp(VecStr x);
 
 #endif /* UTIL_H_ */
